@@ -1,6 +1,7 @@
 from collections import deque
 from contextlib import contextmanager
 import fnmatch
+from glob import glob
 import os
 import re
 import signal
@@ -8,10 +9,10 @@ import sys
 import threading
 import time
 
-from .compat import WIN, glob
 from .ipc import ProcessGroup
 from .logger import DefaultLogger, SilentLogger
 from .utils import (
+    WIN,
     default,
     is_stream_interactive,
     is_watchdog_supported,
@@ -132,21 +133,26 @@ class Reloader(object):
         """
         Execute the reloader forever, blocking the current thread.
 
-        This will invoke ``sys.exit(1)`` if interrupted.
+        This will invoke ``sys.exit`` with the return code from the
+        subprocess. If interrupted before the process starts then
+        it'll exit with ``-1``.
 
         """
+        exitcode = -1
         with self._setup_runtime():
             while True:
-                result = self._run_worker()
-                start = time.time()
-                if result == WorkerResult.WAIT:
-                    result = self._wait_for_changes()
+                result, exitcode = self._run_worker()
                 if result == WorkerResult.EXIT:
                     break
+                start = time.time()
+                if result == WorkerResult.WAIT:
+                    result, _ = self._wait_for_changes()
+                    if result == WorkerResult.EXIT:
+                        break
                 dt = self.reload_interval - (time.time() - start)
                 if dt > 0:
                     time.sleep(dt)
-        sys.exit(1)
+        sys.exit(exitcode)
 
     def run_once(self):
         """
@@ -154,9 +160,12 @@ class Reloader(object):
 
         This method will return after the worker exits.
 
+        Returns the exit code from the worker process.
+
         """
         with self._setup_runtime():
-            self._run_worker()
+            _, exitcode = self._run_worker()
+            return exitcode
 
     def _run_worker(self):
         worker = Worker(
@@ -289,7 +298,8 @@ def _run_worker(self, worker, logger=None, shutdown_interval=None):
 
                     if worker.is_alive:
                         logger.info(
-                            'Worker pipe died unexpectedly, triggering a reload.'
+                            'Worker pipe died unexpectedly, triggering a '
+                            'reload.'
                         )
                         result = WorkerResult.RELOAD
                         break
@@ -368,7 +378,7 @@ def _run_worker(self, worker, logger=None, shutdown_interval=None):
             worker.join()
         logger.debug('Server exited with code %d.' % worker.exitcode)
 
-    return result
+    return result, worker.exitcode
 
 
 def wait_main():
@@ -476,6 +486,11 @@ def start_reloader(
     if shutdown_interval is default:
         shutdown_interval = reload_interval
 
+    if reload_interval <= 0:
+        raise ValueError(
+            'reload_interval must be greater than 0 to avoid spinning'
+        )
+
     reloader = Reloader(
         worker_path=worker_path,
         worker_args=worker_args,
