@@ -1,5 +1,8 @@
+from _thread import interrupt_main
+from importlib.util import source_from_cache
 import os
 import signal
+import site
 import sys
 import sysconfig
 import threading
@@ -7,13 +10,12 @@ import time
 import traceback
 
 from . import ipc
-from .compat import get_py_path, get_site_packages, interrupt_main
 from .interfaces import IReloaderProxy
 from .utils import resolve_spec
 
 
 class WatchSysModules(threading.Thread):
-    """ Poll ``sys.modules`` for imported modules."""
+    """Poll ``sys.modules`` for imported modules."""
 
     poll_interval = 1
     ignore_system_paths = True
@@ -35,7 +37,7 @@ class WatchSysModules(threading.Thread):
         self.stopped = True
 
     def update_paths(self):
-        """ Check sys.modules for paths to add to our path set."""
+        """Check sys.modules for paths to add to our path set."""
         new_paths = []
         with self.lock:
             for path in expand_source_paths(iter_module_paths()):
@@ -46,10 +48,10 @@ class WatchSysModules(threading.Thread):
             self.watch_paths(new_paths)
 
     def search_traceback(self, tb):
-        """ Inspect a traceback for new paths to add to our path set."""
+        """Inspect a traceback for new paths to add to our path set."""
         new_paths = []
         with self.lock:
-            for filename, line, funcname, txt in traceback.extract_tb(tb):
+            for filename, *_ in traceback.extract_tb(tb):
                 path = os.path.abspath(filename)
                 if path not in self.paths:
                     self.paths.add(path)
@@ -73,6 +75,35 @@ class WatchSysModules(threading.Thread):
         return False
 
 
+def get_py_path(path):
+    try:
+        return source_from_cache(path)
+    except ValueError:
+        # fallback for solitary *.pyc files outside of __pycache__
+        return path[:-1]
+
+
+def get_site_packages():  # pragma: no cover
+    try:
+        paths = site.getsitepackages()
+        if site.ENABLE_USER_SITE:
+            paths.append(site.getusersitepackages())
+        return paths
+
+    # virtualenv does not ship with a getsitepackages impl so we fallback
+    # to using distutils if we can
+    # https://github.com/pypa/virtualenv/issues/355
+    except Exception:
+        try:
+            from distutils.sysconfig import get_python_lib
+
+            return [get_python_lib()]
+
+        # just incase, don't fail here, it's not worth it
+        except Exception:
+            return []
+
+
 def get_system_paths():
     paths = get_site_packages()
     for name in {'stdlib', 'platstdlib', 'platlib', 'purelib'}:
@@ -83,7 +114,7 @@ def get_system_paths():
 
 
 def expand_source_paths(paths):
-    """ Convert pyc files into their source equivalents."""
+    """Convert pyc files into their source equivalents."""
     for src_path in paths:
         # only track the source path if we can find it to avoid double-reloads
         # when the source and the compiled path change because on some
@@ -96,7 +127,7 @@ def expand_source_paths(paths):
 
 
 def iter_module_paths(modules=None):
-    """ Yield paths of all imported modules."""
+    """Yield paths of all imported modules."""
     modules = modules or list(sys.modules.values())
     for module in modules:
         try:
@@ -110,7 +141,7 @@ def iter_module_paths(modules=None):
 
 
 class Worker(object):
-    """ A helper object for managing a worker process lifecycle. """
+    """A helper object for managing a worker process lifecycle."""
 
     def __init__(self, spec, args=None, kwargs=None):
         super(Worker, self).__init__()
@@ -259,7 +290,8 @@ def worker_main(spec, pipe, spec_args=None, spec_kwargs=None):
         raise
     finally:
         try:
-            # attempt to send imported paths to the master prior to closing
+            # attempt to send imported paths to the reloader process prior to
+            # closing
             poller.update_paths()
             poller.stop()
             poller.join()
